@@ -2,6 +2,6 @@ pub use self::rename_demo::foo;
 
 pub mod rename_demo {
     pub fn foo() {
-        println!("cargo rename demo");
+        println!("cargo rename demo v2");
     }
 }
\ No newline at end of file
